package cn.estsh.i3plus.core.apiservice.controller.busi;

import cn.estsh.i3plus.core.api.iservice.busi.ISysOrderNoRuleService;
import cn.estsh.i3plus.core.apiservice.util.OrderNoMakeUtil;
import cn.estsh.i3plus.pojo.base.enumutil.ResourceEnumUtil;
import cn.estsh.i3plus.pojo.platform.bean.SysOrderNoRule;
import cn.estsh.impp.framework.base.controller.CoreBaseController;
import cn.estsh.impp.framework.boot.exception.ImppBusiException;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ResultBean;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @Description :系统单号规则管理服务
 * @Reference :
 * @Author : yunhao
 * @CreateDate : 2018-11-21 18:20
 * @Modify:
 **/
@RestController
@Api(description = "系统单号规则管理服务")
@RequestMapping(CoreBaseController.BASE_URL + "/sys-order-no-rule")
public class SysOrderNoRuleController {

    @Autowired
    ISysOrderNoRuleService sysOrderNoRuleService;

    @PostMapping(value = "/insert")
    @ApiOperation(value = "新增单号规则")
    public ResultBean insertSysOrderNoRule(SysOrderNoRule sysOrderNoRule){
        try {
            ValidatorBean.beginValid(sysOrderNoRule)
                    .notNull("name",sysOrderNoRule.getName())
                    .notNull("orderNoRuleCode",sysOrderNoRule.getOrderNoRuleCode())
                    .notNull("orderNoRule",sysOrderNoRule.getOrderNoRule())
                    .checkNotZero("serialNoSeed",sysOrderNoRule.getSerialNoSeed())
                    .checkNotZero("serialNoIncrement",sysOrderNoRule.getSerialNoIncrement())
                    .checkNotZero("serialNoLength",sysOrderNoRule.getSerialNoLength())
                    .checkNotZero("isCycle",sysOrderNoRule.getIsCycle());

            sysOrderNoRuleService.insertSysOrderNoRule(sysOrderNoRule);
            return  ResultBean.success("操作成功").setResultObject(sysOrderNoRule).setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @PutMapping(value = "/update")
    @ApiOperation(value = "修改单号规则")
    public ResultBean updateSysOrderNoRule(SysOrderNoRule sysOrderNoRule){
        try {
            ValidatorBean.beginValid(sysOrderNoRule)
                    .notNull("id",sysOrderNoRule.getId())
                    .notNull("name",sysOrderNoRule.getName())
                    .notNull("orderNoRuleCode",sysOrderNoRule.getOrderNoRuleCode())
                    .notNull("orderNoRule",sysOrderNoRule.getOrderNoRule())
                    .checkNotZero("serialNoSeed",sysOrderNoRule.getSerialNoSeed())
                    .checkNotZero("serialNoIncrement",sysOrderNoRule.getSerialNoIncrement())
                    .checkNotZero("serialNoLength",sysOrderNoRule.getSerialNoLength())
                    .checkNotZero("isCycle",sysOrderNoRule.getIsCycle());

            sysOrderNoRuleService.updateSysOrderNoRule(sysOrderNoRule);
            return  ResultBean.success("操作成功").setResultObject(sysOrderNoRule).setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @GetMapping(value = "/get/{id}")
    @ApiOperation(value = "根据id获取编号规则")
    public ResultBean getSysOrderNoRuleById(@PathVariable("id") String idStr){
        try {
            ValidatorBean.checkNotNull(idStr,"id不能为空");

            SysOrderNoRule sysOrderNoRule = sysOrderNoRuleService.getSysOrderNoRuleById(Long.parseLong(idStr));
            if (sysOrderNoRule != null) {
                return  ResultBean.success("查询成功").setResultObject(sysOrderNoRule).setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
            }else {
                return ResultBean.fail("数据不存在").setCode(ResourceEnumUtil.MESSAGE.EMPTY.getCode());
            }
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @DeleteMapping(value = "/delete/{id}")
    @ApiOperation(value = "根据id删除单号规则")
    public ResultBean deleteSysOrderNoRuleById(@PathVariable("id") String idStr){
        try {
            ValidatorBean.checkNotNull(idStr,"id不能为空");

            sysOrderNoRuleService.deleteSysOrderNoRuleById(Long.parseLong(idStr));
            return  ResultBean.success("操作成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @GetMapping(value = "/get-order-no/{code}")
    @ApiOperation(value = "根据单号规则代码，获取单号")
    public ResultBean getOrderNo(@PathVariable("code") String code){
        try {
            ValidatorBean.checkNotNull(code,"code不能为空");

            SysOrderNoRule sysOrderNoRule = sysOrderNoRuleService.getSysOrderNoRuleCode(code);
            if (sysOrderNoRule == null) {
                return ResultBean.fail("单号规则不存在").setCode(ResourceEnumUtil.MESSAGE.EMPTY.getCode());
            }else {
                sysOrderNoRule = OrderNoMakeUtil.next(sysOrderNoRule);
                sysOrderNoRuleService.updateSysOrderNoRule(sysOrderNoRule);
            }
            return  ResultBean.success("查询成功").setResultObject(sysOrderNoRule).setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

}
