package cn.estsh.i3plus.core.apiservice.mq;

import cn.estsh.i3plus.core.api.iservice.busi.ISysMessageService;
import cn.estsh.i3plus.core.api.iservice.busi.ISysUserService;
import cn.estsh.i3plus.pojo.platform.bean.SysRefUserMessage;
import com.rabbitmq.client.Channel;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.amqp.core.Message;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.io.IOException;

/**
 * @Description : 站内信队列处理
 * @Reference :
 * @Author : yunhao
 * @CreateDate : 2018-11-15 22:35
 * @Modify:
 **/
@Component
public class LetterQueueReceiver {
    private static final Logger LOGGER = LoggerFactory.getLogger(LetterQueueReceiver.class);

    @Autowired
    ISysMessageService sysMessageService;
    @Autowired
    ISysUserService sysUserService;

    /**
     * 站内信处理队列
     * @param msg
     * @param channel
     * @param message
     * 发送：rabbitTemplate.convertAndSend(I3CoreQueueConfig.IMPP_MESSAGE_QUEUE, new SysMessage(....));
     */
//    @RabbitListener(queues = I3CoreQueueConfig.IMPP_MESSAGE_LETTER_QUEUE)
    public void processImppMessage(SysRefUserMessage msg, Channel channel, Message message) {
        try {
            LOGGER.info("【MQ-IMPP_MESSAGE_QUEUE】数据接收成功：{}",msg);

            sysMessageService.insertSysRefUserMessage(msg);

            //信息已处理
            channel.basicAck(message.getMessageProperties().getDeliveryTag(),false);
        } catch (IOException e) {
            LOGGER.error("【MQ-IMPP_MESSAGE_QUEUE】处理出错：{}",e.getMessage(),e);
            //丢弃这条消息
            try {
                // 未成功处理，重新发送
                channel.basicNack(message.getMessageProperties().getDeliveryTag(),false,true);
            } catch (IOException e1) {
                e1.printStackTrace();
            }
        }
    }
}
